summaryrefslogtreecommitdiffstats
path: root/klipper/toplevel.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'klipper/toplevel.cpp')
-rw-r--r--klipper/toplevel.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/klipper/toplevel.cpp b/klipper/toplevel.cpp
index 8b2bcb0eb..15267d3d8 100644
--- a/klipper/toplevel.cpp
+++ b/klipper/toplevel.cpp
@@ -327,7 +327,7 @@ void KlipperWidget::showPopupMenu( TQPopupMenu *menu )
{
Q_ASSERT( menu != 0L );
- TQSize size = menu->sizeHint(); // geometry is not valid until it's shown
+ TQSize size = menu->tqsizeHint(); // tqgeometry is not valid until it's shown
if (bPopupAtMouse) {
TQPoint g = TQCursor::pos();
if ( size.height() < g.y() )
@@ -336,7 +336,7 @@ void KlipperWidget::showPopupMenu( TQPopupMenu *menu )
menu->popup(TQPoint(g.x(), g.y()));
} else {
KWin::WindowInfo i = KWin::windowInfo( winId(), NET::WMGeometry );
- TQRect g = i.geometry();
+ TQRect g = i.tqgeometry();
TQRect screen = KGlobalSettings::desktopGeometry(g.center());
if ( g.x()-screen.x() > screen.width()/2 &&
@@ -380,7 +380,7 @@ bool KlipperWidget::loadHistory() {
TQDataStream* history_stream = &file_stream;
TQByteArray data;
if( !oldfile ) {
- Q_UINT32 crc;
+ TQ_UINT32 crc;
file_stream >> crc >> data;
if( crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() ) != crc ) {
kdWarning() << failed_load_warning << ": " << history_file.errorString() << endl;
@@ -444,7 +444,7 @@ void KlipperWidget::saveHistory() {
for ( const HistoryItem* item = history()->first(); item; item = history()->next() ) {
history_stream << item;
}
- Q_UINT32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
+ TQ_UINT32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
*history_file.dataStream() << crc << data;
}
@@ -1013,13 +1013,13 @@ TQString KlipperWidget::getClipboardHistoryItem(int i)
//
bool KlipperWidget::ignoreClipboardChanges() const
{
- TQWidget *focusWidget = qApp->focusWidget();
- if ( focusWidget )
+ TQWidget *tqfocusWidget = tqApp->tqfocusWidget();
+ if ( tqfocusWidget )
{
- if ( focusWidget->inherits( "QSpinBox" ) ||
- (focusWidget->parentWidget() &&
- focusWidget->inherits("QLineEdit") &&
- focusWidget->parentWidget()->inherits("QSpinWidget")) )
+ if ( tqfocusWidget->inherits( "QSpinBox" ) ||
+ (tqfocusWidget->tqparentWidget() &&
+ tqfocusWidget->inherits("QLineEdit") &&
+ tqfocusWidget->tqparentWidget()->inherits("QSpinWidget")) )
{
return true;
}